| 7 | |
| 8 | template <typename T> |
| 9 | __global__ void dnmat_divide_kernel( |
| 10 | T* dnmat3_vals, T* dnmat1_vals, T* dnmat2_vals, |
| 11 | size_s total_len, const size_s power |
| 12 | ) { |
| 13 | size_l idx = threadIdx.x + blockIdx.x * blockDim.x; |
| 14 | if (idx < total_len) { |
| 15 | if(power == 1) dnmat3_vals[idx] = dnmat1_vals[idx] / dnmat2_vals[idx]; |
| 16 | else dnmat3_vals[idx] = dnmat1_vals[idx] / pow(dnmat2_vals[idx],power); |
| 17 | } |
| 18 | return; |
| 19 | } |
| 20 | |
| 21 | // cpu function of Ddot |
| 22 | template <typename T> |
nothing calls this directly
no outgoing calls
no test coverage detected